@@ -3,16 +3,17 @@ from .base import SCMBackend
 
 class Backend(SCMBackend):
 
-    default_rev_filename = '.revision'
+    default_filename = '.revision'
 
     def init_repo(self):
         from os import path as op
 
         try:
-            assert op.exists(self.path)
+            assert op.exists(self.path or '')
 
             self._repo = self
-            rev_file = self.path if op.isfile(self.path) else op.join(self.path, self.default_rev_filename)
+            filename = self.options.get('filename') or self.default_filename
+            rev_file = self.path if op.isfile(self.path) else op.join(self.path, filename)
             with open(rev_file) as f:
                 self._revision = f.read().strip()
         except (AssertionError, IOError):
